import { ref } from 'vue'
import { defineStore } from 'pinia'

import {
    Gauge,
    LightningSlash,
    Monitor,
    Plugs,
    SmileySad,
    Swap
} from '@/utils/icons'
import type { MenuItemModel } from '@/utils/interfaces'
import { useRoute } from 'vue-router'

export const useMenuStore = defineStore('menu', () => {
    const route = useRoute()
    const navigation = ref<MenuItemModel[]>([
        {
            name: 'Gangguan',
            href: '/home/gangguan',
            icon: LightningSlash,
            expanded: false,
            children: [
                {
                    name: 'Daftar',
                    href: '/home/gangguan/1',
                    icon: LightningSlash,
                    expanded: false,
                    children: [
                        {
                            name: 'Daftar Keluhan Dialihkan Ke Posko Lain',
                            href: '/home/gangguan/1/1',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Melapor Lebih Dari 1 Kali',
                            href: '/home/gangguan/1/2',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Response Time',
                            href: '/home/gangguan/1/3',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Recovery Time',
                            href: '/home/gangguan/1/4',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Selesai Tanpa ID Pelanggan',
                            href: '/home/gangguan/1/5',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Berdasarkan Media',
                            href: '/home/gangguan/1/6',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Gangguan Diselesaikan Mobile APKT',
                            href: '/home/gangguan/1/7',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                    ],
                },
                {
                    name: 'Rekapitulasi',
                    href: '/home/gangguan/2',
                    icon: LightningSlash,
                    expanded: false,
                    children: [
                        {
                            name: 'Rekapitulasi Gangguan All',
                            href: '/home/gangguan/2/1',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Jenis Gangguan',
                            href: '/home/gangguan/2/2',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Jenis Gangguan SE 004',
                            href: '/home/gangguan/2/3',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Posko',
                            href: '/home/gangguan/2/4',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Regu',
                            href: '/home/gangguan/2/5',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Tanggal',
                            href: '/home/gangguan/2/6',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Berdasarkan Media',
                            href: '/home/gangguan/2/7',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Alih  Posko',
                            href: '/home/gangguan/2/8',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Per Status',
                            href: '/home/gangguan/2/9',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Gangguan Diselesaikan Mobile APKT',
                            href: '/home/gangguan/2/10',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Rating Per Posko',
                            href: '/home/gangguan/2/11',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Rating Per Regu',
                            href: '/home/gangguan/2/12',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Koreksi Transaksi Individual',
                            href: '/home/gangguan/2/13',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Cleansing Transaksi TM',
                            href: '/home/gangguan/2/14',
                            icon: LightningSlash,
                            expanded: false,
                            children: [],
                        },
                    ],
                },
            ],
        },
        {
            name: 'Keluhan',
            href: '/home/keluhan',
            icon: SmileySad,
            expanded: false,
            children: [
                {
                    name: 'Daftar',
                    icon: SmileySad,
                    href: '/home/keluhan/1',
                    expanded: false,
                    children: [
                        {
                            name: 'Daftar Keluhan Dialihkan Ke Unit Lain',
                            href: '/home/keluhan/1/1',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Pelanggan Lebih Dari 1 Kali',
                            href: '/home/keluhan/1/2',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Response Time',
                            href: '/home/keluhan/1/3',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Recovery Time',
                            href: '/home/keluhan/1/4',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Selesai Tanpa ID Pelanggan',
                            href: '/home/keluhan/1/5',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Berdasarkan Media',
                            href: '/home/keluhan/1/6',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Daftar Keluhan Selesai di CC123',
                            href: '/home/keluhan/1/7',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                    ],
                },
                {
                    name: 'Rekapitulasi',
                    icon: SmileySad,
                    href: '/home/keluhan/2',
                    expanded: false,
                    children: [
                        {
                            name: 'Rekapitulasi Keluhan All',
                            href: '/home/keluhan/2/1',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Per Fungsi Bidang',
                            href: '/home/keluhan/2/2',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Per Jenis Keluhan',
                            href: '/home/keluhan/2/3',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Per Tanggal',
                            href: '/home/keluhan/2/4',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Per Unit',
                            href: '/home/keluhan/2/5',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Berdasarkan Media',
                            href: '/home/keluhan/2/6',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Keluhan Per Kelompok Keluhan',
                            href: '/home/keluhan/2/7',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                        {
                            name: 'Rekapitulasi Rating Per Unit',
                            href: '/home/keluhan/2/8',
                            icon: SmileySad,
                            expanded: false,
                            children: [],
                        },
                    ],
                },
            ],
        },
        {
            name: 'Monalisa',
            href: '/home/monalisa',
            icon: Monitor,
            expanded: false,
            children: [
                {
                    name: 'Gangguan',
                    icon: Monitor,
                    href: '/home/monalisa/1',
                    expanded: false,
                    children: [
                        {
                            name: 'Rekapitulasi',
                            href: '/home/monalisa/1/1',
                            icon: Monitor,
                            expanded: false,
                            children: [
                                {
                                    name: 'Jumlah Kali  Gangguan',
                                    href: '/home/monalisa/1/1/1',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Recovery Time (RCT) Gangguan',
                                    href: '/home/monalisa/1/1/2',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Response Time (RPT) Gangguan',
                                    href: '/home/monalisa/1/1/3',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Gangguan Per Jenis Gangguan',
                                    href: '/home/monalisa/1/1/4',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Lapor Ulang Gangguan',
                                    href: '/home/monalisa/1/1/5',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi ENS Gangguan',
                                    href: '/home/monalisa/1/1/6',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Gangguan Belum Selesai',
                                    href: '/home/monalisa/1/1/7',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                            ],
                        },
                    ],
                },
                {
                    name: 'Keluhan',
                    icon: Monitor,
                    href: '/home/monalisa/2',
                    expanded: false,
                    children: [
                        {
                            name: 'Rekapitulasi',
                            href: '/home/monalisa/2/1',
                            icon: Monitor,
                            expanded: false,
                            children: [
                                {
                                    name: 'Jumlah Kali  Keluhan',
                                    href: '/home/monalisa/2/1/1',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Recovery Time (RCT) Keluhan',
                                    href: '/home/monalisa/2/1/2',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Response Time (RPT) Keluhan',
                                    href: '/home/monalisa/2/1/3',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Gangguan Per Jenis Keluhan',
                                    href: '/home/monalisa/2/1/4',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Lapor Ulang Keluhan',
                                    href: '/home/monalisa/2/1/5',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Rekapitulasi Keluhan Belum Selesai',
                                    href: '/home/monalisa/2/1/6',
                                    icon: Monitor,
                                    expanded: false,
                                    children: [],
                                },
                            ],
                        },
                    ],
                },
                {
                    name: 'Laporan KPI',
                    icon: Monitor,
                    href: '/home/monalisa/3',
                    expanded: false,
                    children: [
                        {
                            name: 'Bulanan',
                            icon: Monitor,
                            href: '/home/monalisa/3/1',
                            expanded: false,
                            children: [
                                {
                                    name: 'Penurunan Jumlah Komplain',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/1/1',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Aging Complaint',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/1/2',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Energy Not Sales (ENS)',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/1/3',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Kepatuhan dan Akurasi  Dalam Pelaporan',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/1/4',
                                    expanded: false,
                                    children: [],
                                },
                            ],
                        },
                        {
                            name: 'Kumulatif',
                            icon: Monitor,
                            href: '/home/monalisa/3/2',
                            expanded: false,
                            children: [
                                {
                                    name: 'Penurunan Jumlah Komplain',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/2/1',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Aging Complaint',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/2/2',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Energy Not Sales (ENS)',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/2/3',
                                    expanded: false,
                                    children: [],
                                },
                                {
                                    name: 'Kepatuhan dan Akurasi  Dalam Pelaporan',
                                    icon: Monitor,
                                    href: '/home/monalisa/3/2/4',
                                    expanded: false,
                                    children: [],
                                }
                            ],
                        }
                    ],
                },
            ],
        },
        {
            name: 'Check In Dan Check Out',
            href: '/home/check-in-out',
            icon: Swap,
            expanded: false,
            children: [
                {
                    name: 'Laporan Check In /Check Out (CICO)',
                    href: '/home/check-in-out/1',
                    icon: Swap,
                    expanded: false,
                    children: [
                        {
                            name: 'Laporan Check In /Check Out (CICO)',
                            href: '/home/check-in-out/1/1',
                            icon: Swap,
                            expanded: false,
                            children: [],
                        },
                    ],
                },
            ],
        },
        {
            name: 'Anomali Penangan Pengaduan',
            href: '/home/anomali-pengaduan',
            icon: Plugs,
            expanded: false,
            children: [
                {
                    name: 'Gangguan',
                    href: '/home/anomali-pengaduan/1',
                    icon: Plugs,
                    expanded: false,
                    children: [
                        {
                            name: 'Laporan Anomali Penangan Pengaduan Gangguan Unit',
                            href: '/home/anomali-pengaduan/1/1',
                            icon: Plugs,
                            expanded: false,
                            children: []
                        },
                        {
                            name: 'Laporan Anomali Penangan Pengaduan Gangguan Petugas',
                            href: '/home/anomali-pengaduan/1/2',
                            icon: Plugs,
                            expanded: false,
                            children: []
                        },
                    ]
                },
                {
                    name: 'Keluhan',
                    href: '/home/anomali-pengaduan/2',
                    icon: Plugs,
                    expanded: false,
                    children: [
                        {
                            name: 'Laporan Anomali Penangan Pengaduan Keluhan Unit',
                            href: '/home/anomali-pengaduan/2/1',
                            icon: Plugs,
                            expanded: false,
                            children: []
                        }
                    ]
                }
            ]
        },
        {
            name: 'CTT & KWH Periksa',
            href: '/home/ctt-kwh-periksa',
            icon: Gauge,
            expanded: false,
            children: [
                {
                    name: 'Laporan CTT & KWH Periksa',
                    href: '/home/ctt-kwh-periksa/1',
                    icon: Gauge,
                    expanded: false,
                    children: []
                }
            ]
        }
    ])
    const sidebarOpen = ref(false)
    const sidebarShowed = ref(true)
    const menuSelected = ref(route.fullPath)
    const toggleSidebar = () => (sidebarOpen.value = !sidebarOpen.value)
    const toggleSidebarMenu = (href: string, newExpanded: boolean): void => {
        const toggleItemExpanded = (items: MenuItemModel[]): void => {
            for (const item of items) {
                if (item.href === href) {
                    item.expanded = newExpanded
                } else {
                    if (newExpanded) {
                        if (!href.includes(item.href)) {
                            item.expanded = !newExpanded;
                        }
                    }
                }
                if (item.children && item.children.length > 0) {
                    toggleItemExpanded(item.children)
                }
            }
        }

        toggleItemExpanded(navigation.value)
    }
    const toggleSidebarDesktop = () => (sidebarShowed.value = !sidebarShowed.value)

    return {
        navigation,
        toggleSidebar,
        sidebarOpen,
        menuSelected,
        toggleSidebarMenu,
        sidebarShowed,
        toggleSidebarDesktop
    }
})